@@ -16,17 +16,13 @@ class KNotifyConfigElement;
 class KNotifyEventListItem;
 class KConfig;
 
-/**
-    @author Olivier Goffart <ogoffart at kde.org>
-*/
 class KNotifyEventList : public QTreeWidget
 {
     Q_OBJECT
 public:
     explicit KNotifyEventList(QWidget *parent);
     ~KNotifyEventList() override;
-    void fill(const QString &appname, const QString &context_name = QString(),
-              const QString &context_value = QString(), bool loadDefaults = false);
+    void fill(const QString &appname, bool loadDefaults = false);
     void save();
     void updateCurrentItem();
     void updateAllItems();
@@ -46,15 +42,13 @@ private Q_SLOTS:
 
 Q_SIGNALS:
     void eventSelected(KNotifyConfigElement *);
-
 };
 
 class KNotifyEventListItem : public QTreeWidgetItem
 {
 public:
-    KNotifyEventListItem(QTreeWidget *parent, const QString &eventName, const QString &name,
-                         const QString &description, KConfig *confir);
-    ~KNotifyEventListItem();
+    KNotifyEventListItem(QTreeWidget *parent, const QString &eventName, const QString &name, const QString &description, KConfig *confir);
+    ~KNotifyEventListItem() override;
     void save();
 
     KNotifyConfigElement *configElement()
@@ -66,7 +60,6 @@ public:
 
 private:
     KNotifyConfigElement m_config;
-
 };
 
 #endif
